package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherThesis;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * thesisMapper接口
 *
 * @author srs
 * @date 2024-06-29
 */
public interface SysTeacherThesisMapper extends BaseMapper<SysTeacherThesis> {
    /**
     * 查询thesis
     *
     * @param thesisId thesis主键
     * @return thesis
     */
    public SysTeacherThesis selectSysTeacherThesisByThesisId(Long thesisId);

    /**
     * 查询thesis列表
     *
     * @param sysTeacherThesis thesis
     * @return thesis集合
     */
    List<SysTeacherThesis> selectSysTeacherThesisList(SysTeacherThesis sysTeacherThesis);

    /**
     * 新增thesis
     *
     * @param sysTeacherThesis thesis
     * @return 结果
     */
    int insertSysTeacherThesis(SysTeacherThesis sysTeacherThesis);

    /**
     * 修改thesis
     *
     * @param sysTeacherThesis thesis
     * @return 结果
     */
    int updateSysTeacherThesis(SysTeacherThesis sysTeacherThesis);

    /**
     * 删除thesis
     *
     * @param thesisId thesis主键
     * @return 结果
     */
    int deleteSysTeacherThesisByThesisId(Long thesisId);

    /**
     * 批量删除thesis
     *
     * @param thesisIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherThesisByThesisIds(Long[] thesisIds);
}
